import typing
from . import capabilities
from . import matrix
from . import platform
from . import select
from . import shader
from . import state
from . import texture
from . import types

GenericType = typing.TypeVar("GenericType")



import typing

GenericType = typing.TypeVar("GenericType")

class NodeCategory:
    def poll(self, _context): ...

class NodeItem:
    label: typing.Any
    translation_context: typing.Any

    def draw(self, layout, _context): ...

class NodeItemCustom: ...

def draw_node_categories_menu(context): ...
def has_node_categories(context): ...
def node_categories_iter(context): ...
def node_items_iter(context): ...
def register_node_categories(identifier, cat_list): ...
def unregister_node_cat_types(cats): ...
def unregister_node_categories(identifier): ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def bvh(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    filepath: typing.Union[str, typing.Any] = "",
    filter_glob: typing.Union[str, typing.Any] = "*.bvh",
    target: typing.Optional[typing.Any] = "ARMATURE",
    global_scale: typing.Optional[typing.Any] = 1.0,
    frame_start: typing.Optional[typing.Any] = 1,
    use_fps_scale: typing.Optional[typing.Union[bool, typing.Any]] = False,
    update_scene_fps: typing.Optional[typing.Union[bool, typing.Any]] = False,
    update_scene_duration: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_cyclic: typing.Optional[typing.Union[bool, typing.Any]] = False,
    rotate_mode: typing.Optional[typing.Any] = "NATIVE",
    axis_forward: typing.Optional[typing.Any] = "-Z",
    axis_up: typing.Optional[typing.Any] = "Y",
):
    """Load a BVH motion capture file

        :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
        :type execution_context: typing.Optional[typing.Union[int, str]]
        :type undo: typing.Optional[bool]
        :param filepath: File Path, Filepath used for importing the file
        :type filepath: typing.Union[str, typing.Any]
        :param filter_glob: filter_glob
        :type filter_glob: typing.Union[str, typing.Any]
        :param target: Target, Import target type
        :type target: typing.Optional[typing.Any]
        :param global_scale: Scale, Scale the BVH by this value
        :type global_scale: typing.Optional[typing.Any]
        :param frame_start: Start Frame, Starting frame for the animation
        :type frame_start: typing.Optional[typing.Any]
        :param use_fps_scale: Scale FPS, Scale the framerate from the BVH to the current scenes, otherwise each BVH frame maps directly to a Blender frame
        :type use_fps_scale: typing.Optional[typing.Union[bool, typing.Any]]
        :param update_scene_fps: Update Scene FPS, Set the scene framerate to that of the BVH file (note that this nullifies the 'Scale FPS' option, as the scale will be 1:1)
        :type update_scene_fps: typing.Optional[typing.Union[bool, typing.Any]]
        :param update_scene_duration: Update Scene Duration, Extend the scene's duration to the BVH duration (never shortens the scene)
        :type update_scene_duration: typing.Optional[typing.Union[bool, typing.Any]]
        :param use_cyclic: Loop, Loop the animation playback
        :type use_cyclic: typing.Optional[typing.Union[bool, typing.Any]]
        :param rotate_mode: Rotation, Rotation conversion

    QUATERNION
    Quaternion -- Convert rotations to quaternions.

    NATIVE
    Euler (Native) -- Use the rotation order defined in the BVH file.

    XYZ
    Euler (XYZ) -- Convert rotations to euler XYZ.

    XZY
    Euler (XZY) -- Convert rotations to euler XZY.

    YXZ
    Euler (YXZ) -- Convert rotations to euler YXZ.

    YZX
    Euler (YZX) -- Convert rotations to euler YZX.

    ZXY
    Euler (ZXY) -- Convert rotations to euler ZXY.

    ZYX
    Euler (ZYX) -- Convert rotations to euler ZYX.
        :type rotate_mode: typing.Optional[typing.Any]
        :param axis_forward: Forward
        :type axis_forward: typing.Optional[typing.Any]
        :param axis_up: Up
        :type axis_up: typing.Optional[typing.Any]
    """

    ...



import typing
import bpy_extras.asset_utils
import bpy_types

GenericType = typing.TypeVar("GenericType")

class ASSETBROWSER_MT_metadata_preview_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_PT_display(
    bpy_extras.asset_utils.AssetBrowserPanel, bpy_types.Panel, bpy_types._GenericUI
):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def asset_browser_panel_poll(self, context): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_PT_filter(
    bpy_extras.asset_utils.AssetBrowserPanel, bpy_types.Panel, bpy_types._GenericUI
):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def asset_browser_panel_poll(self, context): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_PT_metadata(
    bpy_extras.asset_utils.AssetBrowserPanel, bpy_types.Panel, bpy_types._GenericUI
):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def asset_browser_panel_poll(self, context): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def metadata_prop(self, layout, asset_metadata, propname): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_PT_metadata_preview(
    bpy_extras.asset_utils.AssetMetaDataPanel, bpy_types.Panel, bpy_types._GenericUI
):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_PT_metadata_tags(
    bpy_extras.asset_utils.AssetMetaDataPanel, bpy_types.Panel, bpy_types._GenericUI
):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_UL_metadata_tags(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class AssetBrowserMenu:
    def poll(self, context): ...

class FILEBROWSER_HT_header(bpy_types.Header, bpy_types._GenericUI):
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_asset_browser_buttons(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_MT_bookmarks_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_MT_bookmarks_recents_specials_menu(
    bpy_types.Menu, bpy_types._GenericUI
):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_MT_view_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_PT_advanced_filter(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_PT_bookmarks_recents(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_PT_bookmarks_system(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_PT_bookmarks_volumes(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_translation_context: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_PT_directory_path(bpy_types.Panel, bpy_types._GenericUI):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_header_visible(self, context): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_UL_dir(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FileBrowserMenu:
    def poll(self, context): ...

class FileBrowserPanel:
    bl_space_type: typing.Any

    def poll(self, context): ...

class ASSETBROWSER_MT_catalog(AssetBrowserMenu, bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_MT_context_menu(
    AssetBrowserMenu, bpy_types.Menu, bpy_types._GenericUI
):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_MT_editor_menus(
    AssetBrowserMenu, bpy_types.Menu, bpy_types._GenericUI
):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_MT_select(AssetBrowserMenu, bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class ASSETBROWSER_MT_view(AssetBrowserMenu, bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_MT_context_menu(
    FileBrowserMenu, bpy_types.Menu, bpy_types._GenericUI
):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_MT_editor_menus(
    FileBrowserMenu, bpy_types.Menu, bpy_types._GenericUI
):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_MT_select(FileBrowserMenu, bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_MT_view(FileBrowserMenu, bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_PT_bookmarks_favorites(
    FileBrowserPanel, bpy_types.Panel, bpy_types._GenericUI
):
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_PT_display(FileBrowserPanel, bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class FILEBROWSER_PT_filter(FileBrowserPanel, bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_ui_units_x: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

def asset_path_str_get(_self): ...
def is_option_region_visible(context, space): ...
def panel_poll_is_asset_browsing(context): ...
def panel_poll_is_upper_region(region): ...
def register_props(): ...



import typing

GenericType = typing.TypeVar("GenericType")

def add_scrollback(text, text_type): ...
def autocomplete(_context): ...
def banner(context): ...
def execute(context, _is_interactive): ...
def shell_run(text): ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def add(override_context=None, execution_context=None, undo=None):
    """Add brush by mode type

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def add_gpencil(override_context=None, execution_context=None, undo=None):
    """Add brush for Grease Pencil

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def curve_preset(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    shape: typing.Optional[typing.Any] = "SMOOTH",
):
    """Set brush shape

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param shape: Mode
    :type shape: typing.Optional[typing.Any]
    """

    ...

def reset(override_context=None, execution_context=None, undo=None):
    """Return brush to defaults based on current tool

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...

def scale_size(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    scalar: typing.Optional[typing.Any] = 1.0,
):
    """Change brush size by a scalar

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param scalar: Scalar, Factor to scale brush size by
    :type scalar: typing.Optional[typing.Any]
    """

    ...

def sculpt_curves_falloff_preset(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    shape: typing.Optional[typing.Any] = "SMOOTH",
):
    """Set Curve Falloff Preset

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param shape: Mode
    :type shape: typing.Optional[typing.Any]
    """

    ...

def stencil_control(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    mode: typing.Optional[typing.Any] = "TRANSLATION",
    texmode: typing.Optional[typing.Any] = "PRIMARY",
):
    """Control the stencil brush

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param mode: Tool
    :type mode: typing.Optional[typing.Any]
    :param texmode: Tool
    :type texmode: typing.Optional[typing.Any]
    """

    ...

def stencil_fit_image_aspect(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    use_repeat: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_scale: typing.Optional[typing.Union[bool, typing.Any]] = True,
    mask: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """When using an image texture, adjust the stencil size to fit the image aspect ratio

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param use_repeat: Use Repeat, Use repeat mapping values
    :type use_repeat: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_scale: Use Scale, Use texture scale values
    :type use_scale: typing.Optional[typing.Union[bool, typing.Any]]
    :param mask: Modify Mask Stencil, Modify either the primary or mask stencil
    :type mask: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def stencil_reset_transform(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    mask: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Reset the stencil transformation to the default

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param mask: Modify Mask Stencil, Modify either the primary or mask stencil
    :type mask: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...



import typing
import nodeitems_utils

GenericType = typing.TypeVar("GenericType")

class SortedNodeCategory(nodeitems_utils.NodeCategory):
    def poll(self, _context): ...

class CompositorNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
    def poll(self, context): ...

class ShaderNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
    def poll(self, context): ...

def group_input_output_item_poll(context): ...
def group_tools_draw(_self, layout, _context): ...
def node_group_items(context): ...
def register(): ...
def unregister(): ...



import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class IndexSwitchItemAddOperator(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class IndexSwitchItemRemoveOperator(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class MoveModifierToNodes(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NewGeometryNodeGroupTool(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NewGeometryNodeTreeAssign(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NewGeometryNodesModifier(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class NodeOperator:
    def get_node(self, context): ...
    def poll(self, context): ...

class SocketItemAddOperator:
    active_index_name: typing.Any
    default_socket_type: typing.Any
    items_name: typing.Any

    def execute(self, context): ...

class SocketItemRemoveOperator:
    active_index_name: typing.Any
    items_name: typing.Any

    def execute(self, context): ...

class SocketMoveItemOperator:
    active_index_name: typing.Any
    items_name: typing.Any

    def execute(self, context): ...

class ZoneOperator:
    def get_node(self, context): ...
    def poll(self, context): ...

class BakeNodeOperator(NodeOperator):
    active_index_name: typing.Any
    items_name: typing.Any
    node_type: typing.Any

    def get_node(self, context): ...
    def poll(self, context): ...

class RepeatZoneOperator(ZoneOperator):
    active_index_name: typing.Any
    input_node_type: typing.Any
    items_name: typing.Any
    output_node_type: typing.Any

    def get_node(self, context): ...
    def poll(self, context): ...

class SimulationZoneOperator(ZoneOperator):
    active_index_name: typing.Any
    input_node_type: typing.Any
    items_name: typing.Any
    output_node_type: typing.Any

    def get_node(self, context): ...
    def poll(self, context): ...

class BakeNodeItemAddOperator(
    BakeNodeOperator, SocketItemAddOperator, NodeOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    default_socket_type: typing.Any
    id_data: typing.Any
    items_name: typing.Any
    node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class BakeNodeItemMoveOperator(
    BakeNodeOperator, SocketMoveItemOperator, NodeOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    items_name: typing.Any
    node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class BakeNodeItemRemoveOperator(
    BakeNodeOperator, SocketItemRemoveOperator, NodeOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    items_name: typing.Any
    node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class RepeatZoneItemAddOperator(
    RepeatZoneOperator, ZoneOperator, SocketItemAddOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    default_socket_type: typing.Any
    id_data: typing.Any
    input_node_type: typing.Any
    items_name: typing.Any
    output_node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class RepeatZoneItemMoveOperator(
    RepeatZoneOperator, ZoneOperator, SocketMoveItemOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    input_node_type: typing.Any
    items_name: typing.Any
    output_node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class RepeatZoneItemRemoveOperator(
    RepeatZoneOperator, ZoneOperator, SocketItemRemoveOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    input_node_type: typing.Any
    items_name: typing.Any
    output_node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class SimulationZoneItemAddOperator(
    SimulationZoneOperator, ZoneOperator, SocketItemAddOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    default_socket_type: typing.Any
    id_data: typing.Any
    input_node_type: typing.Any
    items_name: typing.Any
    output_node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class SimulationZoneItemMoveOperator(
    SimulationZoneOperator, ZoneOperator, SocketMoveItemOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    input_node_type: typing.Any
    items_name: typing.Any
    output_node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class SimulationZoneItemRemoveOperator(
    SimulationZoneOperator, ZoneOperator, SocketItemRemoveOperator, bpy_types.Operator
):
    active_index_name: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    input_node_type: typing.Any
    items_name: typing.Any
    output_node_type: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def get_node(self, context): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

def add_empty_geometry_node_group(name): ...
def edit_geometry_nodes_modifier_poll(context): ...
def geometry_modifier_poll(context): ...
def geometry_node_group_empty_modifier_new(name): ...
def geometry_node_group_empty_new(name): ...
def geometry_node_group_empty_tool_new(context): ...
def get_context_modifier(context): ...
def get_enabled_socket_with_name(sockets, name): ...
def get_socket_with_identifier(sockets, identifier): ...
def modifier_attribute_name_get(modifier, identifier): ...
def modifier_input_use_attribute(modifier, identifier): ...
def socket_idname_to_attribute_type(idname): ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def stl(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    filepath: typing.Union[str, typing.Any] = "",
    check_existing: typing.Optional[typing.Union[bool, typing.Any]] = True,
    filter_glob: typing.Union[str, typing.Any] = "*.stl",
    use_selection: typing.Optional[typing.Union[bool, typing.Any]] = False,
    global_scale: typing.Optional[typing.Any] = 1.0,
    use_scene_unit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    ascii: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_mesh_modifiers: typing.Optional[typing.Union[bool, typing.Any]] = True,
    batch_mode: typing.Optional[typing.Any] = "OFF",
    global_space: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0, 0.0),
    ),
    axis_forward: typing.Optional[typing.Any] = "Y",
    axis_up: typing.Optional[typing.Any] = "Z",
):
    """Save STL triangle mesh data

        :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
        :type execution_context: typing.Optional[typing.Union[int, str]]
        :type undo: typing.Optional[bool]
        :param filepath: File Path, Filepath used for exporting the file
        :type filepath: typing.Union[str, typing.Any]
        :param check_existing: Check Existing, Check and warn on overwriting existing files
        :type check_existing: typing.Optional[typing.Union[bool, typing.Any]]
        :param filter_glob: filter_glob
        :type filter_glob: typing.Union[str, typing.Any]
        :param use_selection: Selection Only, Export selected objects only
        :type use_selection: typing.Optional[typing.Union[bool, typing.Any]]
        :param global_scale: Scale
        :type global_scale: typing.Optional[typing.Any]
        :param use_scene_unit: Scene Unit, Apply current scene's unit (as defined by unit scale) to exported data
        :type use_scene_unit: typing.Optional[typing.Union[bool, typing.Any]]
        :param ascii: Ascii, Save the file in ASCII file format
        :type ascii: typing.Optional[typing.Union[bool, typing.Any]]
        :param use_mesh_modifiers: Apply Modifiers, Apply the modifiers before saving
        :type use_mesh_modifiers: typing.Optional[typing.Union[bool, typing.Any]]
        :param batch_mode: Batch Mode

    OFF
    Off -- All data in one file.

    OBJECT
    Object -- Each object as a file.
        :type batch_mode: typing.Optional[typing.Any]
        :param global_space: Global Space, Export in this reference space
        :type global_space: typing.Optional[typing.Any]
        :param axis_forward: Forward
        :type axis_forward: typing.Optional[typing.Any]
        :param axis_up: Up
        :type axis_up: typing.Optional[typing.Any]
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

def backend_type_get() -> str:
    """Get actuve GPU backend.

    :rtype: str
    :return: Backend type ('OPENGL', 'VULKAN', 'METAL', 'NONE', 'UNKNOWN').
    """

    ...

def device_type_get() -> str:
    """Get GPU device type.

    :rtype: str
    :return: Device type ('APPLE', 'NVIDIA', 'AMD', 'INTEL', 'SOFTWARE', 'QUALCOMM', 'UNKNOWN').
    """

    ...

def renderer_get() -> str:
    """Get GPU to be used for rendering.

    :rtype: str
    :return: GPU name.
    """

    ...

def vendor_get() -> str:
    """Get GPU vendor.

    :rtype: str
    :return: Vendor name.
    """

    ...

def version_get() -> str:
    """Get GPU driver version.

    :rtype: str
    :return: Driver version.
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

def addon_keymap_register(keymap_data):
    """Register a set of keymaps for addons using a list of keymaps.See 'blender_defaults.py' for examples of the format this takes."""

    ...

def addon_keymap_unregister(keymap_data):
    """Unregister a set of keymaps for addons."""

    ...

def keyconfig_test(kc): ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def create(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    name: typing.Union[str, typing.Any] = "Collection",
):
    """Create an object collection from selected objects

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param name: Name, Name of the new collection
    :type name: typing.Union[str, typing.Any]
    """

    ...

def objects_add_active(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    collection: typing.Optional[typing.Union[int, str, typing.Any]] = "",
):
    """Add the object to an object collection that contains the active object

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param collection: Collection, The collection to add other selected objects to
    :type collection: typing.Optional[typing.Union[int, str, typing.Any]]
    """

    ...

def objects_remove(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    collection: typing.Optional[typing.Union[int, str, typing.Any]] = "",
):
    """Remove selected objects from a collection

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param collection: Collection, The collection to remove this object from
    :type collection: typing.Optional[typing.Union[int, str, typing.Any]]
    """

    ...

def objects_remove_active(
    override_context=None,
    execution_context=None,
    undo=None,
    *,
    collection: typing.Optional[typing.Union[int, str, typing.Any]] = "",
):
    """Remove the object from an object collection that contains the active object

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    :param collection: Collection, The collection to remove other selected objects from
    :type collection: typing.Optional[typing.Union[int, str, typing.Any]]
    """

    ...

def objects_remove_all(override_context=None, execution_context=None, undo=None):
    """Remove selected objects from all collections

    :type override_context: typing.Optional[typing.Union['bpy.types.Context', typing.Dict]]
    :type execution_context: typing.Optional[typing.Union[int, str]]
    :type undo: typing.Optional[bool]
    """

    ...



import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class PHYSICS_UL_dynapaint_surfaces(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PhysicButtonsPanel:
    bl_context: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any

    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...

class PHYSICS_PT_dp_brush_source(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_brush_source_color_ramp(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_brush_velocity(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_brush_velocity_color_ramp(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_brush_velocity_smudge(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_header(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_brush_wave(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_cache(PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_canvas_initial_color(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_canvas_output(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_canvas_output_paintmaps(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_header(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_canvas_output_wetmaps(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_header(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_effects(PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_effects_drip(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_header(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_effects_drip_weights(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_effects_shrink(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_header(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_effects_spread(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_header(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_surface_canvas(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_surface_canvas_paint_dissolve(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_header(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dp_surface_canvas_paint_dry(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_header(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dynamic_paint(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class PHYSICS_PT_dynamic_paint_settings(
    PhysicButtonsPanel, bpy_types.Panel, bpy_types._GenericUI
):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_dyn_canvas(self, context): ...
    def poll_dyn_canvas_brush(self, context): ...
    def poll_dyn_canvas_paint(self, context): ...
    def poll_dyn_output(self, context): ...
    def poll_dyn_output_maps(self, context): ...
    def poll_dyn_paint(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...



import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class AnnotationDataPanel:
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any

    def draw(self, context): ...
    def draw_header(self, context): ...
    def draw_layers(self, context, layout, gpd): ...

class AnnotationDrawingToolsPanel:
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any

    def draw(self, context): ...

class AnnotationOnionSkin:
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any

    def draw(self, context): ...
    def draw_header(self, context): ...
    def poll(self, context): ...

class GPENCIL_MT_cleanup(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_MT_gpencil_draw_delete(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_MT_layer_active(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_MT_layer_mask_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_MT_material_active(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_MT_move_to_layer(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_MT_snap_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, _context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_UL_annotation_layer(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_UL_layer(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GPENCIL_UL_masks(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GREASE_PENCIL_MT_layer_active(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GREASE_PENCIL_MT_move_to_layer(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def draw(self, context): ...
    def draw_collapsible(self, context, layout): ...
    def draw_preset(self, _context): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_extended(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
    ): ...
    def path_resolve(self): ...
    def pop(self): ...
    def prepend(self, draw_func): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def remove(self, draw_func): ...
    def type_recast(self): ...
    def values(self): ...

class GreasePencilBrushFalloff:
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context): ...

class GreasePencilDisplayPanel:
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context): ...
    def draw_header(self, context): ...
    def poll(self, context): ...

class GreasePencilFlipTintColors(bpy_types.Operator):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore): ...
    def as_pointer(self): ...
    def bl_rna_get_subclass(self): ...
    def bl_rna_get_subclass_py(self): ...
    def driver_add(self): ...
    def driver_remove(self): ...
    def execute(self, context): ...
    def get(self): ...
    def id_properties_clear(self): ...
    def id_properties_ensure(self): ...
    def id_properties_ui(self): ...
    def is_property_hidden(self): ...
    def is_property_overridable_library(self): ...
    def is_property_readonly(self): ...
    def is_property_set(self): ...
    def items(self): ...
    def keyframe_delete(self): ...
    def keyframe_insert(self): ...
    def keys(self): ...
    def path_from_id(self): ...
    def path_resolve(self): ...
    def poll(self, context): ...
    def poll_message_set(self): ...
    def pop(self): ...
    def property_overridable_library_set(self): ...
    def property_unset(self): ...
    def type_recast(self): ...
    def values(self): ...

class GreasePencilLayerAdjustmentsPanel:
    def draw(self, context): ...

class GreasePencilLayerDisplayPanel:
    def draw(self, context): ...

class GreasePencilLayerMasksPanel:
    def draw(self, context): ...
    def draw_header(self, context): ...

class GreasePencilLayerRelationsPanel:
    def draw(self, context): ...

class GreasePencilLayerTransformPanel:
    def draw(self, context): ...

class GreasePencilMaterialsPanel:
    def draw(self, context): ...

class GreasePencilSculptAdvancedPanel:
    def draw(self, context): ...

class GreasePencilSimplifyPanel:
    def draw(self, context): ...
    def draw_header(self, context): ...

class GreasePencilVertexcolorPanel:
    def draw(self, context): ...



import typing

GenericType = typing.TypeVar("GenericType")

def poly_3d_calc(veclist, pt):
    """Calculate barycentric weights for a point on a polygon.

    :param veclist: list of vectors
    :param pt: point   :rtype: list of per-vector weights
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

class MotionPathButtonsPanel:
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any

    def draw_settings(self, _context, avs, mpath, bones): ...

class MotionPathButtonsPanel_display:
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any

    def draw_settings(self, _context, avs, mpath, bones): ...



import typing

GenericType = typing.TypeVar("GenericType")

def create_from_info(shader_info: typing.Any) -> typing.Any:
    """Create shader from a GPUShaderCreateInfo.

    :param shader_info: GPUShaderCreateInfo
    :type shader_info: typing.Any
    :rtype: typing.Any
    :return: Shader object corresponding to the given name.
    """

    ...

def from_builtin(shader_name: str, config: str = "DEFAULT") -> typing.Any:
    """Shaders that are embedded in the blender internal code (see `built-in-shaders`).
    They all read the uniform mat4 ModelViewProjectionMatrix,
    which can be edited by the `gpu.matrix` module.You can also choose a shader configuration that uses clip_planes by setting the CLIPPED value to the config parameter. Note that in this case you also need to manually set the value of mat4 ModelMatrix.

        :param shader_name: One of the builtin shader names.
        :type shader_name: str
        :param config: One of these types of shader configuration:

    DEFAULT

    CLIPPED
        :type config: str
        :rtype: typing.Any
        :return: Shader object corresponding to the given name.
    """

    ...

def unbind():
    """Unbind the bound shader object."""

    ...
